##  Reordering Fact Sheets
Follow these steps:
  1. On the Meta Model Configuration page, click Change order.
  2. Drag and drop fact sheets to reorder them as needed, then click Save order.


The order changes everywhere in the workspace where fact sheets appear.
